@@ -7,7 +7,7 @@ import sys
 
 def _windows_dll_path():
     import os
-    _vtk_python_path = 'lib/python3.10/site-packages/vtkmodules'
+    _vtk_python_path = 'lib/python3.11/site-packages/vtkmodules'
     _vtk_dll_path = 'bin'
     # Compute the DLL path based on the location of the file and traversing up
     # the installation prefix to append the DLL path.
@@ -79,6 +79,7 @@ __all__ = [
     'vtkIOExport',
     'vtkWebGLExporter',
     'vtkFiltersGeneral',
+    'vtkRenderingHyperTreeGrid',
     'vtkRenderingUI',
     'vtkRenderingOpenGL2',
     'vtkFiltersSources',
@@ -108,6 +109,7 @@ __all__ = [
     'vtkRenderingParallelLIC',
     'vtkRenderingParallel',
     'vtkRenderingVR',
+    'vtkRenderingOpenXR',
     'vtkRenderingOpenVR',
     'vtkRenderingMatplotlib',
     'vtkRenderingLOD',
@@ -153,7 +155,6 @@ __all__ = [
     'vtkIOInfovis',
     'vtkIOImport',
     'vtkIOIOSS',
-    'vtkIOHDF',
     'vtkIOH5part',
     'vtkIOH5Rage',
     'vtkIOGeoJSON',
@@ -164,7 +165,9 @@ __all__ = [
     'vtkIOEnSight',
     'vtkIOCityGML',
     'vtkIOChemistry',
+    'vtkIOCesium3DTiles',
     'vtkIOCONVERGECFD',
+    'vtkIOHDF',
     'vtkIOCGNSReader',
     'vtkIOAsynchronous',
     'vtkIOAMR',
@@ -209,18 +212,19 @@ __all__ = [
     'vtkFiltersFlowPaths',
     'vtkFiltersParallelFlowPaths',
     'vtkFiltersParallelDIY2',
-    'vtkFiltersHyperTree',
     'vtkFiltersGeneric',
     'vtkFiltersAMR',
     'vtkDomainsParallelChemistry',
     'vtkFiltersParallelMPI',
     'vtkDomainsChemistryOpenGL2',
+    'vtkFiltersHyperTree',
     'vtkCommonPython',
     'vtkCommonArchive',
     'vtkChartsCore',
     'vtkAcceleratorsVTKmCore',
     'vtkAcceleratorsVTKmDataModel',
     'vtkAcceleratorsVTKmFilters',
+    'all',
     'gtk',
     'numpy_interface',
     'qt',
@@ -232,4 +236,4 @@ __all__ = [
 
 #------------------------------------------------------------------------------
 # get the version
-__version__ = "9.1.0"
+__version__ = "9.2.6"
